@@ -76,29 +76,40 @@ class InitialiseDomainModel(InitialiseDomainModel):
     def createMarkets(self):
         for periodYear in range(self.thisYear, self.thisYear+2):
             for periodMonth in range(1, 13):
-                if periodYear == self.thisYear:
-                    if periodMonth <= self.thisMonth:
-                        continue
+                if periodYear == self.thisYear and periodMonth <= self.thisMonth:
+                    continue
                 periodDay = calendar.monthrange(periodYear,periodMonth)[1]
                 firstDeliveryDate = datetime.datetime(periodYear, periodMonth, periodDay)
-                print "Delivery date: %s" % firstDeliveryDate
+                print "Creating futures market with delivery date: %s" % firstDeliveryDate
                 # Todo: Get expiration from the market data source.
                 expiration = datetime.datetime(periodYear, periodMonth, 1)
-                lastPrice1 = 30
-                referenceDate1 = datetime.datetime(self.thisYear-1, 1, 1)
-                lastPrice2 = 10
-                referenceDate2 = datetime.datetime(self.thisYear, 1, 1)
-                self.timepoint.recorded = referenceDate1
+                price1 = 30
+                date1 = datetime.datetime(self.thisYear-1, 1, 1)
+                price2 = 10
+                date2 = datetime.datetime(self.thisYear, 1, 1)
                 market = self.symbol1.markets.create(
                     expiration=expiration,
                     firstDeliveryDate=firstDeliveryDate,
-                    lastPrice=lastPrice1
                 )
-                self.timepoint.reset()
-                temporalHistory = market.temporalHistory
-                version = market.temporalHistory.create(dateCreated=referenceDate2)
-                version.lastPrice = lastPrice2
-                version.save()
+                market.history.create(observationTime=date1, value=price1)
+                market.history.create(observationTime=date2, value=price2)
+                # Setup option markets.
+                strikePrices = [4, 6, 8, 10, 12, 14, 16]
+                expirations = []
+                for optionYear in range(self.thisYear, self.thisYear+2):
+                    for optionMonth in range(1, 13):
+                        optionDay = calendar.monthrange(optionYear,optionMonth)[1]
+                        optionExpiration = datetime.datetime(optionYear, optionMonth, optionDay)
+                        if optionExpiration > firstDeliveryDate:
+                            continue
+                        expirations.append(optionExpiration)
+                for strikePrice in strikePrices:
+                    for expiration in expirations:
+                        print "Creating options market with expiration date: %s, strike price: %s" % (expiration, strikePrice)
+                        market.europeanOptionMarkets.create(
+                            strikePrice=strikePrice,
+                            expiration=expiration
+                        )
 
     def createPriceProcesses(self):
         self.priceProcessBlackScholes = self.registry.priceProcesses.create(
