@@ -94,7 +94,7 @@ class Option(Derivative):
         )
 
 
-class OptionRight(SimpleNamedObject):
+class OptionRight(NamedObject):
 
     pass
 
@@ -182,7 +182,7 @@ class Futures(Derivative):
         )
 
 
-class FuturesRight(SimpleNamedObject):
+class FuturesRight(NamedObject):
 
     pass
 
