@@ -17,5 +17,5 @@ class BookTestCase(TestCase):
 
     def test_book(self):
         self.assertTrue(self.book)
-        self.assertEqual(len(self.book.getContracts()), 2)
+        self.assertTrue(len(self.book.getContracts()))
 
