@@ -6,6 +6,8 @@ from quant.dom.market import Exchange
 from quant.dom.market import Symbol
 from quant.dom.market import Image
 from quant.dom.market import Market
+from quant.dom.market import EuropeanOptionMarket
+from quant.dom.market import Value
 from quant.dom.market import Metric
 from quant.contracttype.simple import OptionRight
 from quant.contracttype.simple import FuturesRight
@@ -28,6 +30,8 @@ class ModelBuilder(dm.dom.builder.ModelBuilder):
         self.registry.registerDomainClass(Exchange)
         self.registry.registerDomainClass(Symbol)
         self.registry.registerDomainClass(Market)
+        self.registry.registerDomainClass(EuropeanOptionMarket)
+        self.registry.registerDomainClass(Value)
         self.registry.registerDomainClass(Image)
         self.registry.registerDomainClass(Metric)
         self.registry.registerDomainClass(OptionRight)
@@ -37,27 +41,40 @@ class ModelBuilder(dm.dom.builder.ModelBuilder):
         self.registry.registerDomainClass(Result)
         self.registry.apiKeys = ApiKey.createRegister()
         self.registry.exchanges = Exchange.createRegister()
+        Exchange.principalRegister = self.registry.exchanges
         self.registry.symbols = Symbol.createRegister()
+        Symbol.principalRegister = self.registry.symbols
         self.registry.markets = Market.createRegister()
+        Market.principalRegister = self.registry.markets
         self.registry.images = Image.createRegister()
+        Image.principalRegister = self.registry.images
         self.registry.optionRights = OptionRight.createRegister()
+        OptionRight.principalRegister = self.registry.optionRights
         self.registry.futuresRights = FuturesRight.createRegister()
+        FuturesRight.principalRegister = self.registry.futuresRights
         self.registry.books = Book.createRegister()
+        Book.principalRegister = self.registry.books
         self.registry.resultLines = ResultLine.createRegister()
+        ResultLine.principalRegister = self.registry.resultLines
         self.registry.results = Result.createRegister()
+        Result.principalRegister = self.registry.results
         # Extensions.
         self.registry.registerDomainClass(ContractType)
         self.registry.registerDomainClass(PriceProcess)
         self.registry.registerDomainClass(Pricer)
         self.registry.registerDomainClass(PricerPreference)
         self.registry.contractTypes = ContractType.createRegister()
+        ContractType.principalRegister = self.registry.contractTypes
         self.registry.priceProcesses = PriceProcess.createRegister()
+        PriceProcess.principalRegister = self.registry.priceProcesses
         self.registry.pricers = Pricer.createRegister()
+        Pricer.principalRegister = self.registry.pricers
         self.registry.pricerPreferences = PricerPreference.createRegister()
-        self.registry.loadBackgroundRegister(self.registry.contractTypes)
-        self.registry.loadBackgroundRegister(self.registry.priceProcesses)
-        self.registry.loadBackgroundRegister(self.registry.pricers)
-        self.registry.loadBackgroundRegister(self.registry.pricerPreferences)
+        PricerPreference.principalRegister = self.registry.pricerPreferences
+        #self.registry.loadBackgroundRegister(self.registry.contractTypes)
+        #self.registry.loadBackgroundRegister(self.registry.priceProcesses)
+        #self.registry.loadBackgroundRegister(self.registry.pricers)
+        #self.registry.loadBackgroundRegister(self.registry.pricerPreferences)
         # Contracts from contract types.
         for contractType in self.registry.contractTypes:
             try:
@@ -71,4 +88,5 @@ class ModelBuilder(dm.dom.builder.ModelBuilder):
                 registryAttrName = contractClass.getRegistryAttrName() 
                 contractRegister = contractClass.createRegister()
                 setattr(self.registry, registryAttrName, contractRegister)
+                contractClass.principalRegister = contractRegister
 
