@@ -1,10 +1,10 @@
-from quant.dom.base import DatedStatefulObject
+from quant.dom.base import DatedObject
 from quant.dom.base import String
 from quant.dom.base import AggregatesMany
 from quant.dom.base import HasA
 import codecs
 
-class Extension(DatedStatefulObject):
+class Extension(DatedObject):
 
     codeModuleName = String()
     codeClassName = String()
@@ -59,7 +59,7 @@ class Pricer(Extension):
     pricerPreferences = AggregatesMany('PricerPreference', key='id')
 
 
-class PricerPreference(DatedStatefulObject):
+class PricerPreference(DatedObject):
 
     pricer = HasA('Pricer')
     contractType = HasA('ContractType')
