@@ -1,6 +1,7 @@
+import sys
 from quant.dom.base import StandardObject
 from quant.dom.base import SimpleObject
-from quant.dom.base import SimpleNamedObject
+from quant.dom.base import NamedObject
 from quant.dom.base import DatedStatefulObject
 from quant.dom.base import String
 from quant.dom.base import Text 
@@ -16,19 +17,31 @@ import dateutil.parser
 import scipy
 import math
 
-class Exchange(SimpleNamedObject):
+class Exchange(NamedObject):
 
     symbols = AggregatesMany('Symbol', key='name', ownerName='exchange')
     holidays = Text(isRequired=False)
 
 
-class Symbol(SimpleNamedObject):
+class Symbol(NamedObject):
 
     markets = AggregatesMany('Market', key='id')
     exchange = HasA('Exchange', isRequired=True, isSimpleOption=True)
 
 
+class Value(SimpleObject):
+
+    sortOnName = 'observationTime'
+    sortAscending = False
+
+    value = Float(isRequired=True)
+    observationTime = DateTime(isRequired=True)
+    market = HasA('Market', isRequired=True)
+
+
+# Todo: Rename to FuturesMarket.
 class Market(SimpleObject):
+   
 
     monthLetters = ['F', 'G', 'H', 'J', 'K', 'M', 'N', 'Q', 'U', 'V', 'X', 'Z']
 
@@ -38,8 +51,10 @@ class Market(SimpleObject):
     expiration = Date()
     sortOnName = 'firstDeliveryDate'
     symbol = HasA('Symbol', isRequired=True)
-    lastPrice = Float(isTemporal=True, isRequired=True)
+    history = HasMany('Value', key='id')
     metrics = AggregatesMany('Metric', key='id', isEditable=False)
+    europeanOptionMarkets = AggregatesMany('EuropeanOptionMarket', key='id')
+
 
     def getLabelValue(self):
         monthIndex = self.firstDeliveryDate.month - 1
@@ -49,11 +64,30 @@ class Market(SimpleObject):
 
     def calcLastPrice(self, observationTime):
         # Todo: Look up effective value at observation time.
-        return self.lastPrice
+        history = list(self.history)
+        if len(history):
+            return history[0].value
+        else:
+            raise Exception, "Price history has zero length."
 
     def getPriceHistory(self, observationTime):
         # Todo: Return history only until observation time.
-        return ([i for i in self.temporalHistory])
+        return list(self.history)
+
+
+class EuropeanOptionMarket(SimpleObject):
+
+    market = HasA('Market', isRequired=True)
+    strikePrice = Float(isRequired=True)
+    expiration = Date()
+
+    def getLabelValue(self):
+        return self.market.getLabelValue() + '.' + self.expiration.strftime('%c') + '.' + str(self.strikePrice)
+        monthIndex = self.firstDeliveryDate.month - 1
+        monthLetter = self.monthLetters[monthIndex]
+        yearAbbr = str(self.firstDeliveryDate.year)[2:]
+        return '%s.%s.%s' % (self.market.getLabelValue(), self.expiration.strftime('%c'), self.strikePrice)
+
 
 
 class Image(SimpleObject):
