@@ -1,5 +1,5 @@
 from quant.dom.base import SimpleObject
-from quant.dom.base import SimpleDatedObject
+from quant.dom.base import DatedObject
 from quant.dom.base import String
 from quant.dom.base import AggregatesMany
 from quant.dom.base import HasA
@@ -11,7 +11,7 @@ import dateutil.parser
 
 # Todo: Make image metrics and result lines more similar? 
 
-class Result(SimpleDatedObject):
+class Result(DatedObject):
 
     PRESENT_VALUE_METRIC = 'value'
     DELTA_METRIC = 'delta'
