@@ -1,8 +1,37 @@
-from quant.dom.testunit import TestCase
+import abc
+import unittest
+import unittest.case
 import datetime
 
+from quant.dom.testunit import TestCase
+
+
+def ignoreTest(*args):
+    return unittest.TestCase
+
+# def skipBaseTestCase(testCaseClass):
+#     raise Exception(testCaseClass)
+#     if testCaseClass.__name__.endswith('TestCase'):
+#         return unittest.TestCase
+#     else:
+#         return testCaseClass
+
+# class skipBaseTestCase(object):
+#
+#     def __init__(self, *args, **kwds):
+#         self.args = args
+#         self.kwds = kwds
+#
+#     def __call__(self, callable):
+#         if callable().__name__.endswith('TestCase'):
+#             raise Exception("Blah")
+#         return cls
+
+
 class PricerTestCase(TestCase):
 
+    __metaclass__ = abc.ABCMeta
+
     DECIMALS = 4
 
     pricerClass = None
@@ -18,6 +47,7 @@ class PricerTestCase(TestCase):
     daysPerYear = 365
 
     expectedExceptionClass = None
+
     expectedValue = 0
     expectedDelta = None
     expectedGamma = None
@@ -35,7 +65,15 @@ class PricerTestCase(TestCase):
             isPut=self.isPut,
         )
 
-    def test_pricer(self):
+    def testPricerValuation(self):
+        self.assertExpectedValueDeltaGamma(
+            expectedValue=self.expectedValue,
+            expectedDelta=self.expectedDelta,
+            expectedGamma=self.expectedGamma)
+
+    def assertExpectedValueDeltaGamma(self, expectedValue, expectedDelta, expectedGamma):
+        if self.__class__ == PricerTestCase:
+            self.skipTest("Abstract test case...")
         if self.expectedExceptionClass:
             self.assertRaises(self.expectedExceptionClass, self.pricer.calcValue)
             return
@@ -63,3 +101,10 @@ class PricerTestCase(TestCase):
         expectedGamma = round(self.expectedGamma, self.DECIMALS)
         msg = "Gamma: %s  Expected: %s  Strike: %s  Current: %s  Volatility: %s  Rate: %s" % (roundedGamma, expectedGamma, self.strikePrice, self.lastPrice, self.actualHistoricalVolatility, self.annualRiskFreeRate)
         self.assertEqual(roundedGamma, expectedGamma, msg)
+
+
+class MonteCarloPricerTestCase(PricerTestCase):
+
+    DECIMALS = 1
+
+
