@@ -1,5 +1,5 @@
 import os
-os.environ['DJANGO_SETTINGS_MODULE'] = 'quant.django.settings.main'
+os.environ['DJANGO_SETTINGS_MODULE'] = 'quant.djangoapp.settings.main'
 
 import quant.application
 
