@@ -1,3 +1,4 @@
+import unittest
 from dm.testunit import ApplicationTestSuite
 from dm.testunit import TestCase
 from quant.builder import ApplicationBuilder
@@ -10,6 +11,14 @@ VOLATILITY_ZERO = 0.00001
 class TestCase(TestCase):
     "Base class for quant TestCases."
 
+    pass
+    # @classmethod
+    # def setUpClass(cls):
+    #     if cls.__name__.endswith('TestCase'):
+    #         raise unittest.SkipTest("Skip base class tests: %s" % cls)
+    #     super(TestCase, cls).setUpClass()
+
+
 class ApplicationTestSuite(ApplicationTestSuite):
     appBuilderClass = ApplicationBuilder
 
